/*!
 * This is a very simple and easy to use library for parsing of simple configuration files.
 */

pub mod config;